@@ -162,8 +162,6 @@ class Neural_Network:
             dataGen = DataGenerator([sample], self.preprocessor,
                                     training=False, validation=False,
                                     shuffle=False, iterations=None)
-            
-            sampleObj = self.preprocessor.data_io.sample_loader(sample, load_seg=False); #TODO optimize
             # Run prediction process with Keras predict
             pred_list = []
             for batch in dataGen:
@@ -171,6 +169,7 @@ class Neural_Network:
                 pred_list.append(pred_batch)
             pred_seg = np.concatenate(pred_list, axis=0)
             # Postprocess prediction
+            sampleObj = self.preprocessor.cache.pop(sample)
             pred_seg = self.preprocessor.postprocessing(sampleObj, pred_seg,
                                                         activation_output)
             # Backup predicted segmentation
@@ -216,8 +215,6 @@ class Neural_Network:
             dataGen = DataGenerator([sample], self.preprocessor,
                                     training=False, validation=False,
                                     shuffle=False, iterations=None)
-            
-            sampleObj = self.preprocessor.data_io.sample_loader(sample, load_seg=False); #TODO optimize
             # Run prediction process with Keras predict
             pred_list = []
             for batch in dataGen:
@@ -225,6 +222,7 @@ class Neural_Network:
                 pred_list.append(pred_batch)
             pred_seg = np.concatenate(pred_list, axis=0)
             # Postprocess prediction
+            sampleObj = self.preprocessor.cache.pop(sample)
             pred_seg = self.preprocessor.postprocessing(sampleObj, pred_seg,
                                                         activation_output=True)
             # Backup predicted segmentation for current augmentation
